aboutsummaryrefslogtreecommitdiffstats
path: root/src/translation/Veriloggen.v
diff options
context:
space:
mode:
authorYann Herklotz <git@yannherklotz.com>2020-07-14 16:08:58 +0100
committerYann Herklotz <git@yannherklotz.com>2020-07-14 16:08:58 +0100
commit450bda69837b02c20d2fb391bbe7827d1becaac4 (patch)
tree716c6d909fd18df3335080a0e00b4c79256c87ba /src/translation/Veriloggen.v
parent8486b4c046914b1388b68fe906fe267108f84267 (diff)
downloadvericert-450bda69837b02c20d2fb391bbe7827d1becaac4.tar.gz
vericert-450bda69837b02c20d2fb391bbe7827d1becaac4.zip
Change name to Vericert
Diffstat (limited to 'src/translation/Veriloggen.v')
-rw-r--r--src/translation/Veriloggen.v4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/translation/Veriloggen.v b/src/translation/Veriloggen.v
index f5d5fa7..a0be0fa 100644
--- a/src/translation/Veriloggen.v
+++ b/src/translation/Veriloggen.v
@@ -1,5 +1,5 @@
(*
* CoqUp: Verified high-level synthesis.
* Copyright (C) 2020 Yann Herklotz <yann@yannherklotz.com>
*
* This program is free software: you can redistribute it and/or modify
@@ -19,7 +19,7 @@
From compcert Require Import Maps.
From compcert Require Errors.
From compcert Require Import AST.
-From coqup Require Import Verilog HTL Coquplib AssocMap ValueInt.
+From vericert Require Import Verilog HTL Vericertlib AssocMap ValueInt.
Definition transl_list_fun (a : node * Verilog.stmnt) :=
let (n, stmnt) := a in
@@ -1,5 +1,5 @@
(*
- * CoqUp: Verified high-level synthesis.
+ * Vericert: Verified high-level synthesis.
* Copyright (C) 2020 Yann Herklotz <yann@yannherklotz.com>
*